@@ -27,7 +27,6 @@
 #include <atk/atkhypertext.h>
 #include <atk/atkhyperlink.h>
 #include <glib/gi18n-lib.h>
-#include <glib/gmacros.h>
 #include <pango/pango.h>
 #include "gtkhtml.h"
 #include "htmlengine.h"
@@ -84,9 +83,8 @@ static AtkHyperlink * html_a11y_text_get_link (AtkHypertext *hypertext, gint lin
 static gint html_a11y_text_get_n_links (AtkHypertext *hypertext);
 static gint html_a11y_text_get_link_index (AtkHypertext *hypertext, gint char_index);
 
-
 /* Editable text interface. */
-static void 	atk_editable_text_interface_init      (AtkEditableTextIface *iface);
+static void	atk_editable_text_interface_init      (AtkEditableTextIface *iface);
 static void	html_a11y_text_set_text_contents	(AtkEditableText      *text,
 							 const gchar          *string);
 static void	html_a11y_text_insert_text	(AtkEditableText      *text,
@@ -120,7 +118,7 @@ get_n_actions (AtkAction *action)
         return 1;
 }
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 action_get_name (AtkAction *action, gint      i)
 {
         if (i == 0)
@@ -150,7 +148,6 @@ atk_action_interface_init (AtkActionIface *iface)
         iface->get_name = action_get_name;
 }
 
-
 GType
 html_a11y_text_get_type (void)
 {
@@ -212,7 +209,6 @@ html_a11y_text_get_type (void)
 	return type;
 }
 
-
 static void
 atk_component_interface_init (AtkComponentIface *iface)
 {
@@ -351,7 +347,6 @@ html_a11y_text_ref_state_set (AtkObject *accessible)
  * AtkComponent interface
  */
 
-
 static void
 html_a11y_text_get_extents (AtkComponent *component, gint *x, gint *y, gint *width, gint *height, AtkCoordType coord_type)
 {
@@ -399,7 +394,6 @@ html_a11y_text_get_extents (AtkComponent *component, gint *x, gint *y, gint *wid
 	*y -=  top_engine->y_offset;
 }
 
-
 static void
 html_a11y_text_get_size (AtkComponent *component, gint *width, gint *height)
 {
@@ -732,7 +726,6 @@ html_a11y_text_set_selection (AtkText *text, gint selection_num, gint start_offs
 	return html_a11y_text_add_selection (text, start_offset, end_offset);
 }
 
-
 /* Most of the code of the following function is copied from */
 /* libgail-util/gailmisc.c gail_misc_layout_get_run_attributes */
 
@@ -774,7 +767,6 @@ html_a11y_text_get_run_attributes (AtkText *text,
 	attr = html_text_prepare_attrs (t, e->painter);
 	g_return_val_if_fail (attr, NULL);
 
-
 	len = g_utf8_strlen (textstring, -1);
 	iter = pango_attr_list_get_iterator (attr);
 
@@ -1102,7 +1094,7 @@ html_a11y_text_cut_text (AtkEditableText *text,
 
 static void
 html_a11y_text_delete_text	(AtkEditableText *text,
-		  	 gint            start_pos,
+			 gint            start_pos,
 			 gint            end_pos)
 {
 	GtkHTML * html;
@@ -1121,7 +1113,7 @@ html_a11y_text_delete_text	(AtkEditableText *text,
 
 static void
 html_a11y_text_paste_text	(AtkEditableText *text,
-			 	 gint            position)
+				 gint            position)
 {
 	GtkHTML * html;
 	HTMLText *t;
@@ -1141,7 +1133,6 @@ html_a11y_text_paste_text	(AtkEditableText *text,
         g_signal_emit_by_name(html, "grab_focus");
 }
 
-
 static void
 atk_hyper_text_interface_init (AtkHypertextIface *iface)
 {
