@@ -22,10 +22,6 @@
  * Most of these handlers will be auto-connected by libglade.  GtkAction
  * callbacks belong in gtkhtml-editor-actions.c. */
 
-#include "gtkhtml-editor-signals.h"
-
-#include <libgnome/gnome-url.h>
-
 #include "gtkhtml-editor-private.h"
 
 /* Think of this as a Python decorator.  It silences compiler
@@ -183,14 +179,19 @@ cell_properties_set_background_color_cb (GtkhtmlEditor *editor,
                                          HTMLTableCell *cell,
                                          GtkWidget *widget)
 {
+	GtkhtmlColorCombo *combo;
 	GtkHTML *html;
 	GdkColor color;
+	gboolean got_color;
 
+	combo = GTKHTML_COLOR_COMBO (widget);
 	html = gtkhtml_editor_get_html (editor);
-	gtkhtml_color_combo_get_current_color (
-		GTKHTML_COLOR_COMBO (widget), &color);
 
-	html_engine_table_cell_set_bg_color (html->engine, cell, &color);
+	/* The default table cell color is transparent. */
+	got_color = gtkhtml_color_combo_get_current_color (combo, &color);
+
+	html_engine_table_cell_set_bg_color (
+		html->engine, cell, got_color ? &color : NULL);
 }
 
 static void
@@ -463,9 +464,9 @@ gtkhtml_editor_cell_properties_show_window_cb (GtkWidget *window))
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), TRUE);
 
 	widget = WIDGET (CELL_PROPERTIES_COLOR_COMBO);
-	if (cell->have_bg)
-		gtkhtml_color_combo_set_current_color (
-			GTKHTML_COLOR_COMBO (widget), &cell->bg);
+	gtkhtml_color_combo_set_current_color (
+		GTKHTML_COLOR_COMBO (widget),
+		cell->have_bg ? &cell->bg : NULL);
 
 	widget = WIDGET (CELL_PROPERTIES_IMAGE_FILE_CHOOSER);
 	if (cell->have_bgPixmap) {
@@ -566,6 +567,7 @@ gtkhtml_editor_cell_properties_width_changed_cb (GtkWidget *window))
 	GtkAdjustment *adjustment;
 	GtkWidget *widget;
 	gboolean sensitive;
+	gdouble value;
 	gint active;
 
 	editor = extract_gtkhtml_editor (window);
@@ -582,15 +584,16 @@ gtkhtml_editor_cell_properties_width_changed_cb (GtkWidget *window))
 	gtk_widget_set_sensitive (widget, sensitive);
 
 	if (active == SIZE_UNIT_PERCENT) {
-		adjustment->upper = 100;
+		gtk_adjustment_set_upper (adjustment, 100.0);
 		gtk_adjustment_changed (adjustment);
 	} else {
-		adjustment->upper = (gdouble) G_MAXINT;
+		gtk_adjustment_set_upper (adjustment, (gdouble) G_MAXINT);
 		gtk_adjustment_changed (adjustment);
 	}
 
 	/* Clamp the value between the new bounds. */
-	gtk_adjustment_set_value (adjustment, adjustment->value);
+	value = gtk_adjustment_get_value (adjustment);
+	gtk_adjustment_set_value (adjustment, value);
 
 	cell_properties_set (
 		editor, cell_properties_set_width_cb,
@@ -781,12 +784,8 @@ gtkhtml_editor_image_properties_show_window_cb (GtkWidget *window))
 		|| html_object_get_data (parent, "template_image") == NULL)
 		&& image->image_ptr->url != NULL) {
 
-		gchar *filename;
-
-		filename = gtk_html_filename_from_uri (image->image_ptr->url);
-		gtk_file_chooser_set_filename (
-			GTK_FILE_CHOOSER (widget), filename);
-		g_free (filename);
+		gtk_file_chooser_set_uri (
+			GTK_FILE_CHOOSER (widget), image->image_ptr->url);
 	} else
 		gtk_file_chooser_unselect_all (GTK_FILE_CHOOSER (widget));
 
@@ -965,7 +964,7 @@ gtkhtml_editor_image_properties_url_button_clicked_cb (GtkWidget *window))
 	text = gtk_entry_get_text (GTK_ENTRY (widget));
 
 	g_return_if_fail (text != NULL);
-	gnome_url_show (text, NULL);
+	gtkhtml_editor_show_uri (GTK_WINDOW (window), text);
 
 	g_object_unref (editor);
 }
@@ -1593,6 +1592,7 @@ gtkhtml_editor_rule_properties_width_changed_cb (GtkWidget *window))
 	GtkWidget *widget;
 	GtkHTML *html;
 	HTMLRule *rule;
+	gdouble value;
 	gint active;
 
 	editor = extract_gtkhtml_editor (window);
@@ -1606,20 +1606,22 @@ gtkhtml_editor_rule_properties_width_changed_cb (GtkWidget *window))
 	adjustment = gtk_spin_button_get_adjustment (GTK_SPIN_BUTTON (widget));
 
 	if (active == SIZE_UNIT_PERCENT) {
-		adjustment->upper = 100;
+		gtk_adjustment_set_upper (adjustment, 100.0);
 		gtk_adjustment_changed (adjustment);
 	} else {
-		adjustment->upper = (gdouble) G_MAXINT;
+		gtk_adjustment_set_upper (adjustment, (gdouble) G_MAXINT);
 		gtk_adjustment_changed (adjustment);
 	}
 
 	/* Clamp the value between the new bounds. */
-	gtk_adjustment_set_value (adjustment, adjustment->value);
+	value = gtk_adjustment_get_value (adjustment);
+	gtk_adjustment_set_value (adjustment, value);
+	value = gtk_adjustment_get_value (adjustment);
 
 	html_rule_set_length (
 		rule, html->engine,
-		(active == SIZE_UNIT_PX) ? (gint) adjustment->value : 0,
-		(active == SIZE_UNIT_PX) ? 0 : (gint) adjustment->value);
+		(active == SIZE_UNIT_PX) ? (gint) value : 0,
+		(active == SIZE_UNIT_PX) ? 0 : (gint) value);
 
 	g_object_unref (editor);
 }
@@ -1687,6 +1689,27 @@ gtkhtml_editor_table_properties_border_changed_cb (GtkWidget *window,
 	g_object_unref (editor);
 }
 
+AUTOCONNECTED_SIGNAL_HANDLER (void
+gtkhtml_editor_table_properties_color_changed_cb (GtkWidget *window,
+                                                  GtkhtmlColorCombo *combo))
+{
+	GtkhtmlEditor *editor;
+	HTMLTable *table;
+	GtkHTML *html;
+	GdkColor color;
+	gboolean got_color;
+
+	editor = extract_gtkhtml_editor (window);
+	html = gtkhtml_editor_get_html (editor);
+	table = HTML_TABLE (editor->priv->table_object);
+
+	/* The default table color is transparent. */
+	got_color = gtkhtml_color_combo_get_current_color (combo, &color);
+
+	html_engine_table_set_bg_color (
+		html->engine, table, got_color ? &color : NULL);
+}
+
 AUTOCONNECTED_SIGNAL_HANDLER (void
 gtkhtml_editor_table_properties_cols_changed_cb (GtkWidget *window,
                                                  GtkSpinButton *button))
@@ -1861,7 +1884,9 @@ gtkhtml_editor_table_properties_show_window_cb (GtkWidget *window))
 	widget = WIDGET (TABLE_PROPERTIES_BORDER_SPIN_BUTTON);
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (widget), value);
 
-	/* TODO - Initialize color combo */
+	widget = WIDGET (TABLE_PROPERTIES_COLOR_COMBO);
+	gtkhtml_color_combo_set_current_color (
+		GTKHTML_COLOR_COMBO (widget), table->bgColor);
 
 	if (table->bgPixmap != NULL) {
 		gchar *filename;
@@ -1893,6 +1918,7 @@ gtkhtml_editor_table_properties_width_changed_cb (GtkWidget *window))
 	GtkHTML *html;
 	HTMLTable *table;
 	gboolean sensitive;
+	gdouble value;
 	gint active;
 
 	editor = extract_gtkhtml_editor (window);
@@ -1911,19 +1937,21 @@ gtkhtml_editor_table_properties_width_changed_cb (GtkWidget *window))
 	gtk_widget_set_sensitive (widget, sensitive);
 
 	if (active == SIZE_UNIT_PERCENT) {
-		adjustment->upper = 100;
+		gtk_adjustment_set_upper (adjustment, 100.0);
 		gtk_adjustment_changed (adjustment);
 	} else {
-		adjustment->upper = (gdouble) G_MAXINT;
+		gtk_adjustment_set_upper (adjustment, (gdouble) G_MAXINT);
 		gtk_adjustment_changed (adjustment);
 	}
 
 	/* Clamp the value between the new bounds. */
-	gtk_adjustment_set_value (adjustment, adjustment->value);
+	value = gtk_adjustment_get_value (adjustment);
+	gtk_adjustment_set_value (adjustment, value);
+	value = gtk_adjustment_get_value (adjustment);
 
 	html_engine_table_set_width (
 		html->engine, table,
-		sensitive ? (gint) adjustment->value : 0,
+		sensitive ? (gint) value : 0,
 		(active == SIZE_UNIT_PERCENT));
 
 	g_object_unref (editor);
